@@ -50,12 +50,13 @@ PDF::COS.loader = class PDF::Class::Loader
 	my $subtype = from-ast $dict<Subtype>;
 
 	my $type = do given $subtype {
-	    # See [PDF 1.7 - TABLE 8.20 Annotation types]
+	    # See [PDF 32000 Table 169 - Annotation types]
 	    when 'Text'|'Link'|'FreeText'|'Line'|'Square'|'Circle'
 		|'Polygon'|'PolyLine'|'Highlight'|'Underline'|'Squiggly'
 		|'StrikeOut'|'Stamp'|'Caret'|'Ink'|'Popup'|'FileAttachment'
 		|'Sound'|'Movie'|'Widget'|'Screen'|'PrinterMark'|'TrapNet'
 		|'Watermark'    { 'Annot' }
+            when 'Markup3D' { 'ExData' }
             when '3D' { $subtype = 'ThreeD'; 'Annot' }
 	    when 'PS'|'Image'|'Form' { 'XObject' }
             when 'Type1C'|'CIDFontType0C'|'OpenType' {
@@ -98,7 +99,7 @@ PDF::COS.loader = class PDF::Class::Loader
     }
 
     subset ColorSpace-Array of List where {
-        my $elems = .elems;
+        my $elems := .elems;
 
         2 <= $elems <= 5
             && ((my $t = from-ast .[0]) ~~ PDF::COS::Name)
