@@ -19,20 +19,20 @@ role PDF::Filespec
     ## also does ISO_32000::File_specification;
 
     # file specifications may be either a dictionary or a simple text-string
-    my subset file-spec is export(:file-spec) where PDF::COS::TextString|PDF::Filespec;
+    my subset Filespec is export(:Filespec) where PDF::COS::TextString|PDF::Filespec;
 
-    proto sub to-file-spec($, file-spec) is export(:to-file-spec) {*};
-    multi sub to-file-spec(Str $value is rw, file-spec) {
+    proto sub to-filespec($, Filespec) is export(:to-filespec) {*};
+    multi sub to-filespec(Str $value is rw, Filespec) {
         PDF::COS.coerce( $value, PDF::COS::TextString );
     }
-    multi sub to-file-spec(Hash $value is rw, file-spec) {
+    multi sub to-filespec(Hash $value is rw, Filespec) {
         PDF::COS.coerce( $value, PDF::Filespec );
     }
-    multi sub to-file-spec($_, file-spec) is default {
-        fail "unable to coerce to a file-spec: {.perl}";
+    multi sub to-filespec($_, Filespec) is default {
+        fail "unable to coerce to a Filespec: {.perl}";
     }
 
-    has PDF::COS::Name $.Type is entry where 'Filespec'; # (Required if an EF or RF entry is present; recommended always) The type of PDF object that this dictionary describes; shall be Filespec for a file specification dictionary.
+    has PDF::COS::Name $.Type is entry(:alias<type>) where 'Filespec'; # (Required if an EF or RF entry is present; recommended always) The type of PDF object that this dictionary describes; shall be Filespec for a file specification dictionary.
     has PDF::COS::Name $.FS is entry; # (Optional) The name of the file system that shall be used to interpret this file specification. If this entry is present, all other entries in the dictionary shall be interpreted by the designated file system. PDF shall define only one standard file system name, URL; an application can register other names. This entry shall be independent of the F, UF, DOS, Mac, and Unix entries.
     has PDF::COS::ByteString $.F is entry; # (Required if the DOS, Mac, and Unix entries are all absent; amended with the UF entry for PDF 1.7) A file specification string of the form described in 7.11.2, "File Specification Strings," or (if the file system is URL) a uniform resource locator, as described in 7.11.5, "URL Specifications."
     has PDF::COS::TextString $.UF is entry; # (Optional, but recommended if the F entry exists in the dictionary; PDF 1.7) A Unicode text string that provides file specification of the form described in 7.11.2, "File Specification Strings." This is a text string encoded using PDFDocEncoding or UTF-16BE with a leading byte-order marker (as defined in 7.9.2.2, "Text String Type"). The F entry should be included along with this entry for backwards compatibility reasons.
