@@ -8,13 +8,13 @@ use PDF::Class::Type;
 
 class PDF::XObject
     is PDF::COS::Stream
-    does PDF::Class::Type {
+    does PDF::Class::Type::Subtyped {
 
     use PDF::COS::Tie;
     use PDF::COS::Name;
 
-    has PDF::COS::Name $.Type is entry where 'XObject';
+    has PDF::COS::Name $.Type is entry(:alias<type>) where 'XObject';
     my subset XObjectSubtype of  PDF::COS::Name where 'Form'|'Image'|'PS';
-    has XObjectSubtype $.Subtype is entry(:required);
+    has XObjectSubtype $.Subtype is entry(:required, :alias<subtype>);
 
 }
